==> react-native-hotqa-sdk-0.2.2.tgz: package/src/components/Congratulations.js <==
import React, {useEffect} from 'react';
import {View, Image, Text, StyleSheet, TouchableOpacity} from 'react-native';
import {color_blue, color_orange_4} from '../assets/colors';
import ic_circle from '../assets/images/ic_circle.png';
import ic_game from '../assets/images/ic_game.png';
import img_complete from '../assets/images/img_complete.png';
import {useDispatch, useSelector} from 'react-redux';
import SoundManager from '../components/SoundManager';
import {
  REQUEST_SUBMIT_USES_ANSWER,
  REQUEST_DATA_QUESTIONS_SUCCESS,
  REQUEST_CLEAR_DATA,
  REQUEST_POINT,
} from '../redux/actions';
import {hideCotrolAndroid} from '../common/helper';

export default (props) => {
  const {route, navigation} = props;
  const dispatch = useDispatch();

  const point = route.params?.numberAnswer;

  dispatch({type: REQUEST_POINT, payload: {point}});
  dispatch({
    type: REQUEST_DATA_QUESTIONS_SUCCESS,
    payload: {data: null},
  });

  SoundManager.destroy();

  useEffect(() => {
    hideCotrolAndroid();
  }, []);

  const backToHome = () => {
    if (route) {
      dispatch({type: REQUEST_CLEAR_DATA});
      route.params?.nav.goBack();
    }
  };

  const clearAnswer = () => {
    dispatch({
      type: REQUEST_SUBMIT_USES_ANSWER,
      payload: {data: []},
    });

    route.params.isFinish = false;
    route.params.isResult = false;
    navigation.reset({
      routes: [{name: 'Home', params: route.params}],
    });
  };

  const viewResult = () => {
    route.params.isFinish = true;
    route.params.isResult = true;
    navigation.reset({
      routes: [{name: 'Home', params: route.params}],
    });
  };

  return (
    <View style={styles.container}>
      <Image source={ic_circle} style={styles.icCircle} />
      <Image source={ic_game} style={styles.icGame} />
      <Image
        source={img_complete}
        style={styles.imgCenter}
        resizeMode="contain"
      />
      <Text style={styles.txtContent}>{point}</Text>
      <Text style={styles.txtCongratulation}>Chúc mừng bạn!</Text>
      <View style={styles.viewBtn}>
        <TouchableOpacity
          style={styles.btnShowAnswer}
          onPress={() => viewResult()}>
          <Text style={styles.txtBtn}>Xem kết quả</Text>
        </TouchableOpacity>
        <TouchableOpacity style={styles.btnAgain} onPress={() => clearAnswer()}>
          <Text style={[styles.txtBtn, {color: color_orange_4}]}>Làm lại</Text>
        </TouchableOpacity>
      </View>
      <TouchableOpacity
        style={styles.btnNext}
        onPress={() => {
          dispatch({type: REQUEST_CLEAR_DATA});
          route.params?.nav.replace('ListActivityByLesson', {
            lessonId: route.params?.lessonId,
            type: 'review',
          });
        }}>
        <Text style={styles.txtBtn}>Chơi tiếp</Text>
      </TouchableOpacity>
      <TouchableOpacity style={styles.btnHome} onPress={backToHome}>
        <Text style={[styles.txtBtn, {color: 'black'}]}>Trang chủ</Text>
      </TouchableOpacity>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: 'white',
    alignItems: 'center',
    justifyContent: 'center',
  },
  imgCenter: {
    height: 250,
  },
  txtCongratulation: {
    color: '#1C20BF',
    fontSize: 48,
  },
  txtContent: {
    fontSize: 90,
    color: color_orange_4,
    lineHeight: 115,
    fontWeight: 'bold',
  },
  icCircle: {
    position: 'absolute',
    left: 0,
    top: '10%',
  },
  icGame: {
    position: 'absolute',
    right: 0,
    bottom: '15%',
  },
  viewBtn: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    marginVertical: 30,
  },
  btnAgain: {
    width: '20%',
    borderRadius: 20,
    borderWidth: 1,
    borderColor: color_orange_4,
    paddingVertical: 16,
    marginHorizontal: 16,
  },
  btnShowAnswer: {
    width: '20%',
    borderRadius: 20,
    backgroundColor: color_blue,
    paddingVertical: 16,
    marginHorizontal: 16,
  },
  txtBtn: {
    fontSize: 18,
    textAlign: 'center',
    color: 'white',
  },
  btnNext: {
    width: '15%',
    borderRadius: 20,
    backgroundColor: '#9EC3F0',
    paddingVertical: 16,
    position: 'absolute',
    right: 30,
    bottom: 30,
  },
  btnHome: {
    width: '15%',
    borderRadius: 20,
    borderWidth: 1,
    borderColor: 'black',
    paddingVertical: 16,
    position: 'absolute',
    left: 30,
    bottom: 30,
  },
});

==> react-native-hotqa-sdk-0.2.7.tgz: package/src/components/Congratulations.js <==
import React, {useEffect} from 'react';
import {View, Image, Text, StyleSheet, TouchableOpacity} from 'react-native';
import {color_blue, color_orange_4} from '../assets/colors';
import ic_circle from '../assets/images/ic_circle.png';
import ic_game from '../assets/images/ic_game.png';
import img_complete from '../assets/images/img_complete.png';
import {useDispatch, useSelector} from 'react-redux';
import SoundManager from '../components/SoundManager';
import {
  REQUEST_SUBMIT_USES_ANSWER,
  REQUEST_DATA_QUESTIONS_SUCCESS,
  REQUEST_CLEAR_DATA,
  REQUEST_POINT,
} from '../redux/actions';
import {hideCotrolAndroid} from '../common/helper';

export default (props) => {
  const {route, navigation} = props;
  const dispatch = useDispatch();

  const point = route.params?.numberAnswer;

  dispatch({type: REQUEST_POINT, payload: {point}});
  dispatch({
    type: REQUEST_DATA_QUESTIONS_SUCCESS,
    payload: {data: null},
  });

  SoundManager.destroy();

  useEffect(() => {
    hideCotrolAndroid();
  }, []);

  const backToHome = () => {
    if (route) {
      dispatch({type: REQUEST_CLEAR_DATA});
      route.params?.nav.goBack();
    }
  };

  const clearAnswer = () => {
    dispatch({
      type: REQUEST_SUBMIT_USES_ANSWER,
      payload: {data: []},
    });

    route.params.isFinish = false;
    route.params.isResult = false;
    navigation.reset({
      routes: [{name: 'Home', params: route.params}],
    });
  };

  const viewResult = () => {
    route.params.isFinish = true;
    route.params.isResult = true;
    navigation.reset({
      routes: [{name: 'Home', params: route.params}],
    });
  };

  return (
    <View style={styles.container}>
      <Image source={ic_circle} style={styles.icCircle} />
      <Image source={ic_game} style={styles.icGame} />
      <Image
        source={img_complete}
        style={styles.imgCenter}
        resizeMode="contain"
      />
      <Text style={styles.txtContent}>{point}</Text>
      <Text style={styles.txtCongratulation}>Chúc mừng bạn!</Text>
      <View style={styles.viewBtn}>
        <TouchableOpacity
          style={styles.btnShowAnswer}
          onPress={() => viewResult()}>
          <Text style={styles.txtBtn}>Xem kết quả</Text>
        </TouchableOpacity>
        <TouchableOpacity style={styles.btnAgain} onPress={() => clearAnswer()}>
          <Text style={[styles.txtBtn, {color: color_orange_4}]}>Làm lại</Text>
        </TouchableOpacity>
      </View>
      <TouchableOpacity
        style={styles.btnNext}
        onPress={() => {
          dispatch({type: REQUEST_CLEAR_DATA});
          route.params?.nav.replace('ListActivityByLesson', {
            lessonId: route.params?.lesson_id,
            type: 'review',
          });
        }}>
        <Text style={styles.txtBtn}>Chơi tiếp</Text>
      </TouchableOpacity>
      <TouchableOpacity style={styles.btnHome} onPress={backToHome}>
        <Text style={[styles.txtBtn, {color: 'black'}]}>Trang chủ</Text>
      </TouchableOpacity>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: 'white',
    alignItems: 'center',
    justifyContent: 'center',
  },
  imgCenter: {
    height: 250,
  },
  txtCongratulation: {
    color: '#1C20BF',
    fontSize: 48,
  },
  txtContent: {
    fontSize: 90,
    color: color_orange_4,
    lineHeight: 115,
    fontWeight: 'bold',
  },
  icCircle: {
    position: 'absolute',
    left: 0,
    top: '10%',
  },
  icGame: {
    position: 'absolute',
    right: 0,
    bottom: '15%',
  },
  viewBtn: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    marginVertical: 30,
  },
  btnAgain: {
    width: '20%',
    borderRadius: 20,
    borderWidth: 1,
    borderColor: color_orange_4,
    paddingVertical: 16,
    marginHorizontal: 16,
  },
  btnShowAnswer: {
    width: '20%',
    borderRadius: 20,
    backgroundColor: color_blue,
    paddingVertical: 16,
    marginHorizontal: 16,
  },
  txtBtn: {
    fontSize: 18,
    textAlign: 'center',
    color: 'white',
  },
  btnNext: {
    width: '15%',
    borderRadius: 20,
    backgroundColor: '#9EC3F0',
    paddingVertical: 16,
    position: 'absolute',
    right: 30,
    bottom: 30,
  },
  btnHome: {
    width: '15%',
    borderRadius: 20,
    borderWidth: 1,
    borderColor: 'black',
    paddingVertical: 16,
    position: 'absolute',
    left: 30,
    bottom: 30,
  },
});
